@@ -11,6 +11,8 @@
 #'     values to use at each extreme of the range.
 #' @param ... currently ignored
 #'
+#' @return A copy of \code{x}, possibly with some of the spectral data values
+#'   replaced by the value passed to \code{fill}.
 #'
 #' @export
 #'
@@ -72,7 +74,7 @@ clean.filter_spct <-
            qty.out = getOption("photobiology.filter.qty", default = "transmittance"),
            ...) {
     if (is.null(range.s.data)) {
-      if (qty.out == "transmittance") {
+      if (qty.out %in% c("transmittance", "absorptance")) {
         range.s.data <- c(0,1)
       } else {
         range.s.data <- c(0,NA)
@@ -86,6 +88,13 @@ clean.filter_spct <-
                  fill = fill,
                  col.names = "Tfr",
                  ...)
+    } else if (qty.out == "absorptance") {
+      clean_spct(x = T2Afr(x, action = "replace"),
+                 range = range,
+                 range.s.data = range.s.data,
+                 fill = fill,
+                 col.names = "Afr",
+                 ...)
     } else if (qty.out == "absorbance") {
       clean_spct(x = T2A(x, action = "replace"),
                  range = range,
@@ -414,7 +423,7 @@ clean_spct <-
       fill <- c(fill, fill)
     }
     # wavelength range
-    if (is.any_spct(range) || is.numeric(range) && length(range) > 2L) {
+    if (is.generic_spct(range) || is.numeric(range) && length(range) > 2L) {
       range <- range(range, na.rm = TRUE)
     } else {
       if (is.na(range[1])) {
