@@ -7,6 +7,11 @@
 #'
 #' @param x An R object
 #' @param ... additonal named arguments passed down to \code{f}.
+#'
+#' @return A copy of \code{x} with the original spectral data values replaced
+#'   with rescaled values, and the \code{"scaled"} attribute set to a list
+#'   describing the scaling applied.
+#'
 #' @export fscale
 #' @family rescaling functions
 #'
@@ -31,6 +36,7 @@ fscale.default <- function(x, ...) {
 #' @param f character string "mean" or "total" for scaling so taht this summary
 #'   value becomes 1 for the returned object, or the name of a function taking
 #'   \code{x} as first argument and returning a numeric value.
+#' @param target numeric A constant used as target value for scaling.
 #' @param unit.out character Alowed values "energy", and "photon", or its alias
 #'   "quantum"
 #'
@@ -39,17 +45,20 @@ fscale.default <- function(x, ...) {
 fscale.source_spct <- function(x,
                                range = NULL,
                                f = "mean",
+                               target = 1,
                                unit.out = getOption("photobiology.radiation.unit", default="energy"),
                                ...) {
   if (unit.out == "energy") {
     return(fscale_spct(spct = q2e(x, action = "replace"),
                        range = range,
                        f = f,
+                       target = target,
                        col.names = "s.e.irrad"))
   } else if (unit.out %in% c("photon", "quantum") ) {
     return(fscale_spct(spct = e2q(x, action = "replace"),
                        range = range,
                        f = f,
+                       target = target,
                        col.names = "s.q.irrad"))
   } else {
     stop("'unit.out ", unit.out, " is unknown")
@@ -63,18 +72,21 @@ fscale.source_spct <- function(x,
 fscale.response_spct <- function(x,
                                  range = NULL,
                                  f = "mean",
+                                 target = 1,
                                  unit.out = getOption("photobiology.radiation.unit", default="energy"),
                                  ...) {
   if (unit.out == "energy") {
     return(fscale_spct(spct = q2e(x, action = "replace"),
                        range = range,
                        f = f,
+                       target = target,
                        col.names = "s.e.response",
                        ...))
   } else if (unit.out %in% c("photon", "quantum") ) {
     return(fscale_spct(spct = e2q(x, action = "replace"),
                        range = range,
                        f = f,
+                       target = target,
                        col.names = "s.q.response",
                        ...))
   } else {
@@ -91,6 +103,7 @@ fscale.response_spct <- function(x,
 fscale.filter_spct <- function(x,
                                range = NULL,
                                f = "mean",
+                               target = 1,
                                qty.out = getOption("photobiology.filter.qty",
                                                    default = "transmittance"),
                                ...) {
@@ -98,12 +111,14 @@ fscale.filter_spct <- function(x,
     return(fscale_spct(spct = A2T(x, action = "replace"),
                        range = range,
                        f = f,
+                       target = target,
                        col.names = "Tfr",
                        ...))
   } else if (qty.out == "absorbance") {
     return(fscale_spct(spct = T2A(x, action = "replace"),
                        range = range,
                        f = f,
+                       target = target,
                        col.names = "A",
                        ...))
   } else {
@@ -118,11 +133,13 @@ fscale.filter_spct <- function(x,
 fscale.reflector_spct <- function(x,
                                   range = NULL,
                                   f = "mean",
+                                  target = 1,
                                   qty.out = NULL,
                                   ...) {
   return(fscale_spct(spct = x,
                      range = range,
                      f = f,
+                     target = target,
                      col.names = "Rfr",
                      ...))
 }
@@ -134,10 +151,12 @@ fscale.reflector_spct <- function(x,
 fscale.raw_spct <- function(x,
                             range = NULL,
                             f = "mean",
+                            target = 1,
                             ...) {
   return(fscale_spct(spct = x,
                      range = range,
                      f = f,
+                     target = target,
                      col.names = grep("^counts", names(x), value = TRUE),
                      ...))
 }
@@ -149,10 +168,12 @@ fscale.raw_spct <- function(x,
 fscale.cps_spct <- function(x,
                             range = NULL,
                             f = "mean",
+                            target = 1,
                             ...) {
   return(fscale_spct(spct = x,
                      range = range,
                      f = f,
+                     target = target,
                      col.names = grep("^cps", names(x), value = TRUE),
                      ...))
 }
@@ -167,11 +188,13 @@ fscale.cps_spct <- function(x,
 fscale.generic_spct <- function(x,
                             range = NULL,
                             f = "mean",
+                            target = 1,
                             col.names,
                             ...) {
   return(fscale_spct(spct = x,
                      range = range,
                      f = f,
+                     target = target,
                      col.names = col.names,
                      ...))
 }
@@ -185,13 +208,15 @@ fscale.generic_spct <- function(x,
 fscale.source_mspct <- function(x,
                                  range = NULL,
                                  f = "mean",
-                                 unit.out = getOption("photobiology.radiation.unit",
+                                target = 1,
+                                unit.out = getOption("photobiology.radiation.unit",
                                                       default = "energy"),
                                  ...) {
   msmsply(x,
           fscale,
           range = range,
           f = f,
+          target = target,
           unit.out = unit.out,
           ...)
 }
@@ -203,6 +228,7 @@ fscale.source_mspct <- function(x,
 fscale.response_mspct <- function(x,
                                   range = NULL,
                                   f = "mean",
+                                  target = 1,
                                   unit.out = getOption("photobiology.radiation.unit",
                                                        default = "energy"),
                                   ...) {
@@ -210,6 +236,7 @@ fscale.response_mspct <- function(x,
           fscale,
           range = range,
           f = f,
+          target = target,
           unit.out = unit.out,
           ...)
 }
@@ -221,13 +248,15 @@ fscale.response_mspct <- function(x,
 fscale.filter_mspct <- function(x,
                                   range = NULL,
                                   f = "mean",
-                                  qty.out = getOption("photobiology.filter.qty",
+                                target = 1,
+                                qty.out = getOption("photobiology.filter.qty",
                                                       default = "transmittance"),
                                   ...) {
   msmsply(x,
           fscale,
           range = range,
           f = f,
+          target = target,
           qty.out = qty.out,
           ...)
 }
@@ -239,12 +268,14 @@ fscale.filter_mspct <- function(x,
 fscale.reflector_mspct <- function(x,
                                   range = NULL,
                                   f = "mean",
+                                  target = 1,
                                   qty.out = NULL,
                                   ...) {
   msmsply(x,
           fscale,
           range = range,
           f = f,
+          target = target,
           qty.out = qty.out,
           ...)
 }
@@ -256,11 +287,13 @@ fscale.reflector_mspct <- function(x,
 fscale.raw_mspct <- function(x,
                              range = NULL,
                              f = "mean",
+                             target = 1,
                              ...) {
   msmsply(x,
           fscale,
           range = range,
           f = f,
+          target = target,
           ...)
 }
 
@@ -271,11 +304,13 @@ fscale.raw_mspct <- function(x,
 fscale.cps_mspct <- function(x,
                              range = NULL,
                              f = "mean",
+                             target = 1,
                              ...) {
   msmsply(x,
           fscale,
           range = range,
           f = f,
+          target = target,
           ...)
 }
 
@@ -286,12 +321,14 @@ fscale.cps_mspct <- function(x,
 fscale.generic_mspct <- function(x,
                              range = NULL,
                              f = "mean",
+                             target = 1,
                              col.names,
                              ...) {
   msmsply(x,
           fscale,
           range = range,
           f = f,
+          target = target,
           col.names = col.names,
           ...)
 }
@@ -315,7 +352,12 @@ fscale.generic_mspct <- function(x,
 #'
 #' @keywords internal
 #'
-fscale_spct <- function(spct, range, col.names, f, ...) {
+fscale_spct <- function(spct, range, col.names, f, target, ...) {
+  # re-scaling will wipe out any existing normalization
+  if (is_normalized(spct)) {
+    setNormalized(spct, norm = FALSE)
+  }
+
   if (is.null(range) || all(is.na(range))) {
     range <- range(spct)
   } else {
@@ -352,11 +394,15 @@ fscale_spct <- function(spct, range, col.names, f, ...) {
     } else {
       summary.value <- 1 # implemented in this way to ensure that all returned
       # values folow the same copy/reference semantics
+      if (target != 1) {
+        warning("No summary function supplied\n",
+                "spectral values multiplied by 'target'")
+      }
     }
-    multipliers[i] <- 1 / summary.value
+    multipliers[i] <- target / summary.value
     spct[[col]] <- spct[[col]] * multipliers[i]
   }
-  setScaled(spct, list(multiplier = multipliers, f = f))
+  setScaled(spct, list(multiplier = multipliers, f = f, range = range, target = target))
   spct
 }
 
@@ -377,7 +423,7 @@ fscale_spct <- function(spct, range, col.names, f, ...) {
 #' @family rescaling functions
 #'
 is_scaled <- function(x) {
-  if (!is.any_spct(x) && !is.any_summary_spct(x)) {
+  if (!is.generic_spct(x) && !is.summary_generic_spct(x)) {
     return(NA)
   }
   spct.attr <- attr(x, "scaled", exact = TRUE)
@@ -401,11 +447,20 @@ is_scaled <- function(x) {
 #' @family Rfr attribute functions
 #'
 getScaled <- function(x) {
-  if (is.any_spct(x) || is.any_summary_spct(x)) {
+  if (is.generic_spct(x) || is.summary_generic_spct(x)) {
     scaled <- attr(x, "scaled", exact = TRUE)
     if (is.null(scaled) || is.na(scaled)) {
       # need to handle objects created with old versions
       scaled <- FALSE
+    } else if (is.list(scaled)) {
+      if (!"target" %in% names(scaled)) {
+        # cater for objects scaled before version 0.9.12
+        scaled <- c(scaled, list(target = 1))
+      }
+      if (!"range" %in% names(scaled)) {
+        # cater for objects scaled before version 0.9.12
+        scaled <- c(scaled, list(range = c(NA_real_, NA_real_)))
+      }
     }
     return(scaled)
   } else {
@@ -429,7 +484,7 @@ getScaled <- function(x) {
 #'
 setScaled <- function(x, scaled = FALSE) {
   name <- substitute(x)
-  if ((is.any_spct(x) || is.any_summary_spct(x)) && !is.null(scaled)) {
+  if ((is.generic_spct(x) || is.summary_generic_spct(x)) && !is.null(scaled)) {
     attr(x, "scaled") <- scaled
     if (is.name(name)) {
       name <- as.character(name)
