@@ -28,13 +28,22 @@
 #'   of ratios, as rescaling and normalization do not invalidate the calculation
 #'   of ratios.
 #'
-#' @return One numeric value for each waveband with no change in scale factor,
-#'   with name attribute set to the name of each waveband unless a named list is
-#'   supplied in which case the names of the list elements are used. The
-#'   time.unit attribute is copied from the spectrum object to the output. Units
-#'   are as follows: If time.unit is second, [W m-2 nm-1] -> [mol s-1 m-2] or [W
-#'   m-2 nm-1] -> [W m-2] If time.unit is day, [J d-1 m-2 nm-1] -> [mol d-1 m-2]
-#'   or [J d-1 m-2 nm-1] -> [J m-2]
+#' @return A named \code{numeric} vector in the case of methods for individual
+#'   spectra, with one value for each \code{waveband} passed to parameter
+#'   \code{w.band}. A \code{data.frame} in the case of collections of spectra,
+#'   containing one column for each \code{waveband} object, an index column with
+#'   the names of the spectra, and optionally additional columns with metadata
+#'   values retrieved from the attributes of the member spectra.
+#'
+#'   By default values are only integrated, but depending on the argument passed
+#'   to parameter \code{quantity} they can be re-expressed as relative fractions
+#'   or percentages. In the case of vector output, \code{names} attribute is set
+#'   to the name of the corresponding waveband unless a named list is supplied
+#'   in which case the names of the list members are used. The \code{time.unit}
+#'   attribute is copied from the spectrum object to the output. Units are as
+#'   follows: If time.unit is second, [W m-2 nm-1] -> [mol s-1 m-2] or [W m-2
+#'   nm-1] -> [W m-2] If time.unit is day, [J d-1 m-2 nm-1] -> [mol d-1 m-2] or
+#'   [J d-1 m-2 nm-1] -> [J m-2]
 #'
 #' @export
 #' @examples
@@ -320,12 +329,21 @@ irrad_spct <- irrad.source_spct
 #' e_irrad(sun.spct, split_bands(c(400,700), length.out = 3),
 #'         quantity = "contribution.pc")
 #'
-#' @return One numeric value for each waveband with no change in scale factor,
-#'   with name attribute set to the name of each waveband unless a named list is
-#'   supplied in which case the names of the list elements are used. The
-#'   time.unit attribute is copied from the spectrum object to the output. Units
-#'   are as follows: If units are absolute and time.unit is second, [W m-2 nm-1]
-#'   -> [W m-2] If time.unit is day, [J d-1 m-2 nm-1] -> [J m-2]; if units are
+#' @return A named \code{numeric} vector in the case of methods for individual
+#'   spectra, with one value for each \code{waveband} passed to parameter
+#'   \code{w.band}. A \code{data.frame} in the case of collections of spectra,
+#'   containing one column for each \code{waveband} object, an index column with
+#'   the names of the spectra, and optionally additional columns with metadata
+#'   values retrieved from the attributes of the member spectra.
+#'
+#'   By default values are only integrated, but depending on the argument passed
+#'   to parameter \code{quantity} they can be re-expressed as relative fractions
+#'   or percentages. In the case of vector output, \code{names} attribute is set
+#'   to the name of the corresponding waveband unless a named list is supplied
+#'   in which case the names of the list members are used. The  time.unit
+#'   attribute is copied from the spectrum object to the output. Units are as
+#'   follows: If units are absolute and time.unit is second, [W m-2 nm-1] -> [W
+#'   m-2] If time.unit is day, [J d-1 m-2 nm-1] -> [J m-2]; if units are
 #'   relative, fraction of one or percent.
 #'
 #' @note The last two parameters control speed optimizations. The defaults
@@ -397,8 +415,6 @@ e_irrad.source_spct <-
 #'   as argument to spct are flagged as an error
 #' @param ... other arguments (possibly ignored)
 #'
-#'
-#'
 #' @export
 #'
 #' @examples
@@ -411,12 +427,21 @@ e_irrad.source_spct <-
 #' q_irrad(sun.spct, split_bands(c(400,700), length.out = 3), quantity = "contribution")
 #' q_irrad(sun.spct, split_bands(c(400,700), length.out = 3), quantity = "contribution.pc")
 #'
-#' @return One numeric value for each waveband with no change in scale factor,
-#'   with name attribute set to the name of each waveband unless a named list is
-#'   supplied in which case the names of the list elements are used. The
-#'   time.unit attribute is copied from the spectrum object to the output. Units
-#'   are as follows: If time.unit is second, [W m-2 nm-1] -> [mol s-1 m-2] If
-#'   time.unit is day, [J d-1 m-2 nm-1] -> [mol d-1 m-2]
+#' @return A named \code{numeric} vector in the case of methods for individual
+#'   spectra, with one value for each \code{waveband} passed to parameter
+#'   \code{w.band}. A \code{data.frame} in the case of collections of spectra,
+#'   containing one column for each \code{waveband} object, an index column with
+#'   the names of the spectra, and optionally additional columns with metadata
+#'   values retrieved from the attributes of the member spectra.
+#'
+#'   By default values are only integrated, but depending on the argument passed
+#'   to parameter \code{quantity} they can be re-expressed as relative fractions
+#'   or percentages. In the case of vector output, \code{names} attribute is set
+#'   to the name of the corresponding waveband unless a named list is supplied
+#'   in which case the names of the list members are used. The time.unit
+#'   attribute is copied from the spectrum object to the output. Units are as
+#'   follows: If time.unit is second, [W m-2 nm-1] -> [mol s-1 m-2] If time.unit
+#'   is day, [J d-1 m-2 nm-1] -> [mol d-1 m-2]
 #'
 #' @note The last two parameters control speed optimizations. The defaults
 #'   should be suitable in mosts cases. If you will use repeatedly the same SWFs
@@ -740,6 +765,8 @@ e_fluence.source_spct <-
 
 #' @describeIn irrad  Calculates irradiance from a \code{source_mspct}
 #'   object.
+#'
+#' @param attr2tb character vector, see \code{\link{add_attr2tb}} for the syntax for \code{attr2tb} passed as is to formal parameter \code{col.names}.
 #' @param idx logical whether to add a column with the names of the elements of
 #'   spct
 #'
@@ -755,24 +782,30 @@ irrad.source_mspct <-
            use.hinges = NULL,
            allow.scaled = !quantity  %in% c("average", "mean", "total"),
            ...,
+           attr2tb = NULL,
            idx = !is.null(names(spct))) {
-    msdply(
-      mspct = spct,
-      .fun = irrad,
-      w.band = w.band,
-      unit.out = unit.out,
-      wb.trim = wb.trim,
-      use.cached.mult = use.cached.mult,
-      use.hinges = use.hinges,
-      allow.scaled = allow.scaled,
-      idx = idx,
-      col.names = names(w.band)
-    )
+    z <-
+      msdply(
+        mspct = spct,
+        .fun = irrad,
+        w.band = w.band,
+        unit.out = unit.out,
+        wb.trim = wb.trim,
+        use.cached.mult = use.cached.mult,
+        use.hinges = use.hinges,
+        allow.scaled = allow.scaled,
+        idx = idx,
+        col.names = names(w.band)
+      )
+    add_attr2tb(tb = z,
+                mspct = spct,
+                col.names = attr2tb)
   }
 
 #' @describeIn q_irrad  Calculates photon (quantum) irradiance from a
 #'   \code{source_mspct} object.
 #'
+#' @param attr2tb character vector, see \code{\link{add_attr2tb}} for the syntax for \code{attr2tb} passed as is to formal parameter \code{col.names}.
 #' @param idx logical whether to add a column with the names of the elements of
 #'   spct
 #'
@@ -787,23 +820,29 @@ q_irrad.source_mspct <-
            use.hinges = NULL,
            allow.scaled = !quantity  %in% c("average", "mean", "total"),
            ...,
+           attr2tb = NULL,
            idx = !is.null(names(spct))) {
-    msdply(
-      mspct = spct,
-      .fun = q_irrad,
-      w.band = w.band,
-      wb.trim = wb.trim,
-      use.cached.mult = use.cached.mult,
-      use.hinges = use.hinges,
-      allow.scaled = allow.scaled,
-      idx = idx,
-      col.names = names(w.band)
-    )
+    z <-
+      msdply(
+        mspct = spct,
+        .fun = q_irrad,
+        w.band = w.band,
+        wb.trim = wb.trim,
+        use.cached.mult = use.cached.mult,
+        use.hinges = use.hinges,
+        allow.scaled = allow.scaled,
+        idx = idx,
+        col.names = names(w.band)
+      )
+    add_attr2tb(tb = z,
+                mspct = spct,
+                col.names = attr2tb)
   }
 
 #' @describeIn e_irrad  Calculates energy irradiance from a
 #'   \code{source_mspct} object.
 #'
+#' @param attr2tb character vector, see \code{\link{add_attr2tb}} for the syntax for \code{attr2tb} passed as is to formal parameter \code{col.names}.
 #' @param idx logical whether to add a column with the names of the elements of
 #'   spct
 #'
@@ -818,22 +857,29 @@ e_irrad.source_mspct <-
            use.hinges = NULL,
            allow.scaled = !quantity  %in% c("average", "mean", "total"),
            ...,
+           attr2tb = NULL,
            idx = !is.null(names(spct))) {
-    msdply(
-      mspct = spct,
-      .fun = e_irrad,
-      w.band = w.band,
-      wb.trim = wb.trim,
-      use.cached.mult = use.cached.mult,
-      use.hinges = use.hinges,
-      allow.scaled = allow.scaled,
-      idx = idx,
-      col.names = names(w.band)
-    )
+    z <-
+      msdply(
+        mspct = spct,
+        .fun = e_irrad,
+        w.band = w.band,
+        wb.trim = wb.trim,
+        use.cached.mult = use.cached.mult,
+        use.hinges = use.hinges,
+        allow.scaled = allow.scaled,
+        idx = idx,
+        col.names = names(w.band)
+      )
+    add_attr2tb(tb = z,
+                mspct = spct,
+                col.names = attr2tb)
   }
 
 #' @describeIn fluence Calculates fluence from a \code{source_mspct}
 #'   object.
+#'
+#' @param attr2tb character vector, see \code{\link{add_attr2tb}} for the syntax for \code{attr2tb} passed as is to formal parameter \code{col.names}.
 #' @param idx logical whether to add a column with the names of the elements of
 #'   spct
 #'
@@ -847,24 +893,32 @@ fluence.source_mspct <-
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
            allow.scaled = FALSE,
-           ..., idx = !is.null(names(spct))) {
-    msdply(
-      mspct = spct,
-      .fun = fluence,
-      w.band = w.band,
-      unit.out = unit.out,
-      exposure.time = exposure.time,
-      wb.trim = wb.trim,
-      use.cached.mult = use.cached.mult,
-      use.hinges = use.hinges,
-      allow.scaled = allow.scaled,
-      idx = idx,
-      col.names = names(w.band)
-    )
+           ...,
+           attr2tb = NULL,
+           idx = !is.null(names(spct))) {
+    z <-
+      msdply(
+        mspct = spct,
+        .fun = fluence,
+        w.band = w.band,
+        unit.out = unit.out,
+        exposure.time = exposure.time,
+        wb.trim = wb.trim,
+        use.cached.mult = use.cached.mult,
+        use.hinges = use.hinges,
+        allow.scaled = allow.scaled,
+        idx = idx,
+        col.names = names(w.band)
+      )
+    add_attr2tb(tb = z,
+                mspct = spct,
+                col.names = attr2tb)
   }
 
 #' @describeIn e_fluence Calculates energy fluence from a \code{source_mspct}
 #'   object.
+#'
+#' @param attr2tb character vector, see \code{\link{add_attr2tb}} for the syntax for \code{attr2tb} passed as is to formal parameter \code{col.names}.
 #' @param idx logical whether to add a column with the names of the elements of spct
 #'
 #' @export
@@ -876,23 +930,31 @@ e_fluence.source_mspct <-
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
            allow.scaled = FALSE,
-           ..., idx = !is.null(names(spct))) {
-    msdply(
-      mspct = spct,
-      .fun = e_fluence,
-      w.band = w.band,
-      exposure.time = exposure.time,
-      wb.trim = wb.trim,
-      use.cached.mult = use.cached.mult,
-      use.hinges = use.hinges,
-      allow.scaled = allow.scaled,
-      idx = idx,
-      col.names = names(w.band)
-    )
+           ...,
+           attr2tb = NULL,
+           idx = !is.null(names(spct))) {
+    z <-
+      msdply(
+        mspct = spct,
+        .fun = e_fluence,
+        w.band = w.band,
+        exposure.time = exposure.time,
+        wb.trim = wb.trim,
+        use.cached.mult = use.cached.mult,
+        use.hinges = use.hinges,
+        allow.scaled = allow.scaled,
+        idx = idx,
+        col.names = names(w.band)
+      )
+    add_attr2tb(tb = z,
+                mspct = spct,
+                col.names = attr2tb)
   }
 
 #' @describeIn q_fluence Calculates photon (quantum) fluence from a
 #'   \code{source_mspct} object.
+#'
+#' @param attr2tb character vector, see \code{\link{add_attr2tb}} for the syntax for \code{attr2tb} passed as is to formal parameter \code{col.names}.
 #' @param idx logical whether to add a column with the names of the elements of
 #'   spct
 #'
@@ -905,18 +967,24 @@ q_fluence.source_mspct <-
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
            allow.scaled = FALSE,
-           ..., idx = !is.null(names(spct))) {
-    msdply(
-      mspct = spct,
-      .fun = q_fluence,
-      w.band = w.band,
-      exposure.time = exposure.time,
-      wb.trim = wb.trim,
-      use.cached.mult = use.cached.mult,
-      use.hinges = use.hinges,
-      allow.scaled = allow.scaled,
-      idx = idx,
-      col.names = names(w.band)
-    )
+           ...,
+           attr2tb = NULL,
+           idx = !is.null(names(spct))) {
+    z <-
+      msdply(
+        mspct = spct,
+        .fun = q_fluence,
+        w.band = w.band,
+        exposure.time = exposure.time,
+        wb.trim = wb.trim,
+        use.cached.mult = use.cached.mult,
+        use.hinges = use.hinges,
+        allow.scaled = allow.scaled,
+        idx = idx,
+        col.names = names(w.band)
+      )
+    add_attr2tb(tb = z,
+                mspct = spct,
+                col.names = attr2tb)
   }
 
