@@ -25,10 +25,20 @@
 #'   defaults should be suitable in mosts cases. Only the range of wavelengths
 #'   in the wavebands is used and all BSWFs are ignored.
 #'
-#' @return A single numeric value expressed either as a fraction of one or a
-#'   percentage, or a vector of the same length as the list of wave.bands. The
-#'   quantity returned depends on the value of \code{quantity}. Whether it is
-#'   expressed in energy-based or photon-based units depends on \code{unit.out}.
+#' @return A named \code{numeric} vector in the case of methods for individual
+#'   spectra, with one value for each \code{waveband} passed to parameter
+#'   \code{w.band}. A \code{data.frame} in the case of collections of spectra,
+#'   containing one column for each \code{waveband} object, an index column with
+#'   the names of the spectra, and optionally additional columns with metadata
+#'   values retrieved from the attributes of the member spectra.
+#'
+#'   Whether returnes values are expressed in energy-based or photon-based units
+#'   depends on \code{unit.out}. By default values are only integrated, but
+#'   depending on the argument passed to parameter \code{quantity} they can be
+#'   re-expressed as relative fractions or percentages. In the case of vector
+#'   output, \code{names} attribute is set to the name of the corresponding
+#'   waveband unless a named list is supplied in which case the names of the
+#'   list members are used.
 #'
 #' @export
 #' @family response functions
@@ -260,10 +270,18 @@ resp_spct <-
 #'   interpolation errors
 #' @param ... other arguments
 #'
-#' @return A single numeric value expressed either as a fraction of one or a
-#'   percentage, or a vector of the same length as the list of wave.bands. The
-#'   quantity returned, although always on energy-based units, depends on the
-#'   value of \code{quantity}.
+#' @return A named \code{numeric} vector in the case of methods for individual
+#'   spectra, with one value for each \code{waveband} passed to parameter
+#'   \code{w.band}. A \code{data.frame} in the case of collections of spectra,
+#'   containing one column for each \code{waveband} object, an index column with
+#'   the names of the spectra, and optionally additional columns with metadata
+#'   values retrieved from the attributes of the member spectra.
+#'
+#'   By default values are only integrated, but depending on the argument passed
+#'   to parameter \code{quantity} they can be re-expressed as relative fractions
+#'   or percentages. In the case of vector output, \code{names} attribute is set
+#'   to the name of the corresponding waveband unless a named list is supplied
+#'   in which case the names of the list members are used.
 #'
 #' @export
 #' @examples
@@ -323,10 +341,18 @@ e_response.response_spct <-
 #'   interpolation errors
 #' @param ... other arguments
 #'
-#' @return A single numeric value expressed either as a fraction of one or a
-#'   percentage, or a vector of the same length as the list of wave.bands. The
-#'   quantity returned, although always on photon-based units, depends on the
-#'   value of \code{quantity}.
+#' @return A named \code{numeric} vector in the case of methods for individual
+#'   spectra, with one value for each \code{waveband} passed to parameter
+#'   \code{w.band}. A \code{data.frame} in the case of collections of spectra,
+#'   containing one column for each \code{waveband} object, an index column with
+#'   the names of the spectra, and optionally additional columns with metadata
+#'   values retrieved from the attributes of the member spectra.
+#'
+#'   By default values are only integrated, but depending on the argument passed
+#'   to parameter \code{quantity} they can be re-expressed as relative fractions
+#'   or percentages. In the case of vector output, \code{names} attribute is set
+#'   to the name of the corresponding waveband unless a named list is supplied
+#'   in which case the names of the list members are used.
 #'
 #' @export
 #' @examples
@@ -375,6 +401,7 @@ q_response.response_spct <-
 
 #' @describeIn response Calculates response from a \code{response_mspct}
 #'
+#' @param attr2tb character vector, see \code{\link{add_attr2tb}} for the syntax for \code{attr2tb} passed as is to formal parameter \code{col.names}.
 #' @param idx logical whether to add a column with the names of the elements of
 #'   spct
 #'
@@ -387,24 +414,31 @@ response.response_mspct <-
            time.unit = NULL,
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
            use.hinges = getOption("photobiology.use.hinges", default = NULL),
-           ..., idx = !is.null(names(spct))) {
-    msdply(
-      mspct = spct,
-      .fun = response,
-      w.band = w.band,
-      unit.out = unit.out,
-      quantity = quantity,
-      time.unit = time.unit,
-      wb.trim = wb.trim,
-      use.hinges = use.hinges,
-      idx = idx,
-      col.names = names(w.band)
-    )
+           ...,
+           attr2tb = NULL,
+           idx = !is.null(names(spct))) {
+    z <-
+      msdply(
+        mspct = spct,
+        .fun = response,
+        w.band = w.band,
+        unit.out = unit.out,
+        quantity = quantity,
+        time.unit = time.unit,
+        wb.trim = wb.trim,
+        use.hinges = use.hinges,
+        idx = idx,
+        col.names = names(w.band)
+      )
+    add_attr2tb(tb = z,
+                mspct = spct,
+                col.names = attr2tb)
   }
 
 #' @describeIn q_response Calculates photon (quantum) response from a
 #'   \code{response_mspct}
 #'
+#' @param attr2tb character vector, see \code{\link{add_attr2tb}} for the syntax for \code{attr2tb} passed as is to formal parameter \code{col.names}.
 #' @param idx logical whether to add a column with the names of the elements of
 #'   spct
 #'
@@ -416,23 +450,30 @@ q_response.response_mspct <-
            time.unit = NULL,
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
            use.hinges = getOption("photobiology.use.hinges", default = NULL),
-           ..., idx = !is.null(names(spct))) {
-    msdply(
-      mspct = spct,
-      .fun = q_response,
-      w.band = w.band,
-      quantity = quantity,
-      time.unit = time.unit,
-      wb.trim = wb.trim,
-      use.hinges = use.hinges,
-      idx = idx,
-      col.names = names(w.band)
-    )
+           ...,
+           attr2tb = NULL,
+           idx = !is.null(names(spct))) {
+    z <-
+      msdply(
+        mspct = spct,
+        .fun = q_response,
+        w.band = w.band,
+        quantity = quantity,
+        time.unit = time.unit,
+        wb.trim = wb.trim,
+        use.hinges = use.hinges,
+        idx = idx,
+        col.names = names(w.band)
+      )
+    add_attr2tb(tb = z,
+                mspct = spct,
+                col.names = attr2tb)
   }
 
 #' @describeIn e_response Calculates energy response from a
 #'   \code{response_mspct}
 #'
+#' @param attr2tb character vector, see \code{\link{add_attr2tb}} for the syntax for \code{attr2tb} passed as is to formal parameter \code{col.names}.
 #' @param idx logical whether to add a column with the names of the elements of
 #'   spct
 #'
@@ -444,16 +485,22 @@ e_response.response_mspct <-
            time.unit = NULL,
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
            use.hinges = getOption("photobiology.use.hinges", default = NULL),
-           ..., idx = !is.null(names(spct))) {
-    msdply(
-      mspct = spct,
-      .fun = e_response,
-      w.band = w.band,
-      quantity = quantity,
-      time.unit = time.unit,
-      wb.trim = wb.trim,
-      use.hinges = use.hinges,
-      idx = idx,
-      col.names = names(w.band)
-    )
+           ...,
+           attr2tb = NULL,
+           idx = !is.null(names(spct))) {
+    z <-
+      msdply(
+        mspct = spct,
+        .fun = e_response,
+        w.band = w.band,
+        quantity = quantity,
+        time.unit = time.unit,
+        wb.trim = wb.trim,
+        use.hinges = use.hinges,
+        idx = idx,
+        col.names = names(w.band)
+      )
+    add_attr2tb(tb = z,
+                mspct = spct,
+                col.names = attr2tb)
   }
