@@ -5,11 +5,15 @@
 #'
 #' Spectra are tagged by adding variables and attributes containing color
 #' definitions, labels, and a factor following the wavebands given in
-#' \code{w.band}.
+#' \code{w.band}. This methods are most useful for plotting realistic
+#' computed colors from spectral data.
 #'
 #' @param x an R object
 #' @param ... not used in current version
 #'
+#' @return A copy of \code{x} expanded with additional columns with
+#'   color-related information.
+#'
 #' @export tag
 #'
 #' @family tagging and related functions
@@ -124,7 +128,7 @@ tag.generic_spct <- function(x,
     }
     wbs.wl.low[i] <- min(wb)
     wbs.wl.high[i] <- max(wb)
-    wbs.rgb[i] <- color(wb)[1]
+    wbs.rgb[i] <- color_of(wb)[1]
   }
   # We add the waveband-independent tags to the spectrum
   x[["wl.color"]] <- w_length2rgb(x[["w.length"]])
@@ -139,7 +143,9 @@ tag.generic_spct <- function(x,
   }
   x[["wb.f"]] <- factor(x[["wb.f"]], levels = wbs.name)
   # We add an attribute with tagging data
-  tag.data <- list(time.unit = getTimeUnit(x),
+  #   field "valid" is a patch to solve a bug in a quick and safe way
+  tag.data <- list(valid = TRUE, # NA's in time.unit at position 1 results in bug
+                   time.unit = getTimeUnit(x),
                    wb.key.name = "Bands",
                    wl.color = TRUE,
                    wb.color = TRUE,
@@ -163,7 +169,7 @@ tag.generic_spct <- function(x,
 #' @export
 #'
 tag.generic_mspct <- function(x,
-                              w.band = NA,
+                              w.band = NULL,
                               wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
                               use.hinges = TRUE,
                               short.names = TRUE,
@@ -312,7 +318,7 @@ wb2rect_spct <- function(w.band, short.names = TRUE) {
     wbs.wl.low[i] <- min(wb)
     wbs.wl.mid[i] <- midpoint(wb)
     wbs.wl.high[i] <- max(wb)
-    wbs.rgb[i] <- color(wb)[1]
+    wbs.rgb[i] <- color_of(wb)[1]
   }
   new.spct <- tibble::tibble(w.length = wbs.wl.mid,
                                 counts = 0, cps = 0,
@@ -350,6 +356,7 @@ wb2rect_spct <- function(w.band, short.names = TRUE) {
 #'
 #' @param x an R object
 #' @param ... not used in current version
+#'
 #' @export untag
 #'
 #' @family tagging and related functions
