@@ -8,7 +8,7 @@
 #'
 #' @param spct an object of class "generic_spct"
 #' @param range a numeric vector of length two, or any other object for which
-#'   function range() will return two
+#'   function range() will return a numeric vector of length two
 #' @param low.limit shortest wavelength to be kept (defaults to shortest
 #'   w.length value)
 #' @param high.limit longest wavelength to be kept (defaults to longest w.length
@@ -49,7 +49,7 @@ trim_spct <- function(spct,
   if (nrow(spct) == 0) {
     return(spct)
   }
-  stopifnot(is.any_spct(spct))
+  stopifnot(is.generic_spct(spct))
   x <- spct
   num.spectra <- getMultipleWl(x)
   if (num.spectra != 1) {
@@ -206,6 +206,7 @@ trim_spct <- function(spct,
   spct
 }
 
+
 #' @rdname trim_spct
 #'
 #' @param mspct an object of class "generic_mspct"
@@ -239,6 +240,49 @@ trim_mspct <- function(mspct,
   z
 }
 
+#' @rdname trim_spct
+#'
+#' @export
+#'
+trim2overlap <- function(mspct,
+                         use.hinges = TRUE,
+                         verbose = getOption("photobiology.verbose", default = TRUE)) {
+  stopifnot(is.any_mspct(mspct))
+  if (length(mspct) < 2) {
+    # nothing to do
+    return(mspct)
+  }
+  ranges <- msdply(mspct, range)
+  range <- with(ranges, c(max(min.wl), min(max.wl)))
+  trim_mspct(mspct,
+             range = range,
+             use.hinges = use.hinges,
+             fill = NULL,
+             verbose = verbose)
+}
+
+#' @rdname trim_spct
+#'
+#' @export
+#'
+extend2extremes <- function(mspct,
+                            use.hinges = TRUE,
+                            fill = NA,
+                            verbose = getOption("photobiology.verbose", default = TRUE)) {
+  stopifnot(is.any_mspct(mspct))
+  if (length(mspct) < 2) {
+    # nothing to do
+    return(mspct)
+  }
+  ranges <- msdply(mspct, range)
+  range <- with(ranges, c(min(min.wl), max(max.wl)))
+  trim_mspct(mspct,
+             range = range,
+             use.hinges = use.hinges,
+             fill = fill,
+             verbose = verbose)
+}
+
 #' Trim head and/or tail of a spectrum
 #'
 #' Triming of head and tail of a spectrum based on wavelength limits,
@@ -252,8 +296,9 @@ trim_mspct <- function(mspct,
 #'   are filled with the value of fill.
 #' @param ... not used
 #'
-#' @return an R object of same class as input, usually of a different
-#'   length, either shorter or longer.
+#' @return A copy of \code{x}, usually trimmed or expanded to a different
+#'   length, either shorter or longer. Possibly with some of the original
+#'   spectral data values replaced with \code{fill}.
 #'
 #' @note By default the \code{w.length} values for the first and last rows
 #'   in the returned object are the values supplied as \code{range}.
@@ -374,8 +419,8 @@ trim_wl.list <- function(x,
 #'   nanometres.
 #' @param ... not used
 #'
-#' @return an R object of same class as input, most frequently of a shorter
-#'   length, and never longer.
+#' @return A copy of \code{x}, most frequently of a shorter length, and never
+#'   longer.
 #'
 #' @note The condition tested is \code{wl >= range[1] & wl < (range[2] + 1e-13)}.
 #'
@@ -411,7 +456,7 @@ clip_wl.generic_spct <- function(x, range = NULL, ...) {
     return(x)
   }
   guard <- 1e-13
-  stopifnot(is.any_spct(x))
+  stopifnot(is.generic_spct(x))
   stopifnot(!all(is.na(range)))
   if (is.numeric(range) && length(range) == 2) {
     if (is.na(range[1])) {
