@@ -13,7 +13,7 @@
 #' @param use.hinges logical, if TRUE (the default) hinges are inserted when
 #'   trimming.
 #'
-#' @return a waveband object or a list of waveband objects trimmed or filtered
+#' @return A waveband object or a list of waveband objects trimmed or filtered
 #'   depending on whether a single waveband object or a list of waveband
 #'   objects was supplied as argument to formal parameter \code{w.band}.
 #'
@@ -86,7 +86,7 @@ trim_waveband <-
       if (length(w.band.out) == 1L) {
         w.band.out <- w.band.out[[1]]
       } else {
-        w.band.out <- NULL
+        w.band.out <- waveband()
       }
     }
     w.band.out
