@@ -13,7 +13,8 @@
 #' mspct_classes()
 #'
 mspct_classes <- function() {
-  c("raw_mspct", "cps_mspct",
+  c("calibration_mspct",
+    "raw_mspct", "cps_mspct",
     "filter_mspct", "reflector_mspct",
     "source_mspct", "object_mspct",
     "response_mspct", "chroma_mspct", "generic_mspct")
@@ -110,7 +111,7 @@ shared_member_class <- function(l, target.set = spct_classes()) {
 generic_mspct <- function(l = NULL, class = "generic_spct",
                           ncol = 1, byrow = FALSE,
                           dim = c(length(l) %/% ncol, ncol)) {
-  if (is.any_spct(l)) {
+  if (is.generic_spct(l)) {
     l <- list(l)
   }
   if (is.null(l)) {
@@ -152,6 +153,15 @@ generic_mspct <- function(l = NULL, class = "generic_spct",
   l
 }
 
+#' @describeIn generic_mspct Specialization for collections of \code{calibration_spct} objects.
+#'
+#' @export
+#' @exportClass calibration_mspct
+#'
+raw_mspct <- function(l = NULL, ncol = 1, byrow = FALSE, ...) {
+  generic_mspct(l, class = "calibration_spct", ncol = ncol, byrow = byrow)
+}
+
 #' @describeIn generic_mspct Specialization for collections of \code{raw_spct} objects.
 #'
 #' @export
@@ -249,6 +259,11 @@ chroma_mspct <- function(l = NULL, ncol = 1, byrow = FALSE, ...) {
 #'
 is.generic_mspct <- function(x) inherits(x, "generic_mspct")
 
+#' @rdname is.generic_mspct
+#' @export
+#'
+is.calibration_mspct <- function(x) inherits(x, "calibration_mspct")
+
 #' @rdname is.generic_mspct
 #' @export
 #'
@@ -333,6 +348,17 @@ as.generic_mspct <- function(x, force.spct.class = FALSE) {
   generic_mspct(y)
 }
 
+#' @rdname as.generic_mspct
+#'
+#' @export
+#'
+as.calibration_mspct <- function(x) {
+  y <- x
+  rmDerivedMspct(y)
+  z <- plyr::llply(y, setCalibrationSpct)
+  raw_mspct(z)
+}
+
 #' @rdname as.generic_mspct
 #'
 #' @export
@@ -476,7 +502,7 @@ split2mspct <- function(x,
                         ncol = 1, byrow = FALSE, ...) {
   stopifnot(!is.null(member.class) || !is.character(member.class))
   stopifnot(!is.null(spct.data.var) || !is.character(spct.data.var))
-  if (is.any_spct(x) && getMultipleWl(x) != 1) {
+  if (is.generic_spct(x) && getMultipleWl(x) != 1) {
     stop("'split2mspct()' is for slicing vertically wide data in data frames ",
          "'subset2mspct()' is used in the case of tidy data in long form.")
   }
@@ -602,6 +628,22 @@ split2raw_mspct <- function(x,
               ...)
 }
 
+#' @rdname split2mspct
+#' @export
+#'
+split2calibration_mspct <- function(x,
+                            spct.data.var = "irrad.mult",
+                            w.length.var = "w.length", idx.var = NULL,
+                            ncol = 1, byrow = FALSE, ...) {
+  split2mspct(x = x,
+              member.class = "calibration_spct",
+              spct.data.var = spct.data.var,
+              w.length.var = w.length.var,
+              idx.var = idx.var,
+              ncol = ncol, byrow = byrow,
+              ...)
+}
+
 #' @title Convert 'long' or tidy spectral data into a collection of spectra
 #'
 #' @description Convert a data frame object or spectral object into a collection
@@ -638,7 +680,7 @@ subset2mspct <- function(x,
                          drop.idx = TRUE,
                          ncol = 1, byrow = FALSE, ...) {
   stopifnot(is.data.frame(x))
-  if (is.any_spct(x) && is.null(member.class)) {
+  if (is.generic_spct(x) && is.null(member.class)) {
     member.class <- class(x)[1]
   }
   stopifnot(is.character(member.class))
@@ -684,7 +726,7 @@ subset2mspct <- function(x,
   if (!is.null(comment)) {
     z <- msmsply(z, `comment<-`, value = comment)
   }
-  if (!is.any_spct(x)) {
+  if (!is.generic_spct(x)) {
     return(z)
   }
   if (is_scaled(x)) {
